@@ -5,7 +5,7 @@
 ;; Author: Omar Antolín Camarena <omar@matem.unam.mx>, Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Omar Antolín Camarena <omar@matem.unam.mx>, Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2020
-;; Version: 0.9
+;; Version: 0.10
 ;; Package-Requires: ((emacs "26.1"))
 ;; Homepage: https://github.com/minad/marginalia
 
@@ -145,10 +145,12 @@ determine it."
   :type '(alist :key-type symbol :value-type symbol))
 
 (defcustom marginalia-bookmark-type-transformers
-  `(("\\`bookmark-\\(.*?\\)-handler\\'" . "\\1")
-    ("default" . "File")
-    ("\\`\\(.*?\\)-+bookmark-jump\\(?:-handler\\)?\\'" . "\\1")
-    (".*" . ,#'capitalize))
+  (let ((words (regexp-opt '("handle" "handler" "jump" "bookmark"))))
+    `((,(format "-+%s-+" words) . "-")
+      (,(format "\\`%s-+" words) . "")
+      (,(format "-%s\\'" words) . "")
+      ("\\`default\\'" . "File")
+      (".*" . ,#'capitalize)))
   "List of bookmark type transformers."
   :type '(alist :key-type regexp :value-type (choice string function)))
 
@@ -558,7 +560,7 @@ keybinding since CAND includes it."
   "Return the variable value of SYM as string."
   (cond
    ((not (boundp sym))
-    (propertize "<unbound>" 'face 'marginalia-null))
+    (propertize "#<unbound>" 'face 'marginalia-null))
    ((and marginalia-censor-variables
          (let ((name (symbol-name sym)))
            (seq-find (lambda (r)
@@ -571,13 +573,20 @@ keybinding since CAND includes it."
         (pcase (symbol-value sym)
           ('nil (propertize "nil" 'face 'marginalia-null))
           ('t (propertize "t" 'face 'marginalia-true))
-          ((pred keymapp) (propertize "<keymap>" 'face 'marginalia-value))
-          ((pred hash-table-p) (propertize "<hash-table>" 'face 'marginalia-value))
+          ((pred keymapp) (propertize "#<keymap>" 'face 'marginalia-value))
+          ((pred bool-vector-p) (propertize "#<bool-vector>" 'face 'marginalia-value))
+          ((pred hash-table-p) (propertize "#<hash-table>" 'face 'marginalia-value))
+          ((pred syntax-table-p) (propertize "#<syntax-table>" 'face 'marginalia-value))
+          ;; Emacs BUG: abbrev-table-p throws an error
+          ((guard (ignore-errors (abbrev-table-p val))) (propertize "#<abbrev-table>" 'face 'marginalia-value))
+          ((pred char-table-p) (propertize "#<char-table>" 'face 'marginalia-value))
+          ((pred byte-code-function-p) (propertize "#<byte-code-function>" 'face 'marginalia-function))
           ((and (pred functionp) (pred symbolp))
            ;; NOTE: We are not consistent here, values are generally printed unquoted. But we
            ;; make an exception for function symbols to visually distinguish them from symbols.
            ;; I am not entirely happy with this, but we should not add quotation to every type.
            (propertize (format "#'%s" val) 'face 'marginalia-function))
+          ((pred recordp) (propertize (format "#<record %s>" (type-of val)) 'face 'marginalia-value))
           ((pred symbolp) (propertize (symbol-name val) 'face 'marginalia-symbol))
           ((pred numberp) (propertize (number-to-string val) 'face 'marginalia-number))
           (_ (let ((print-escape-newlines t)
@@ -925,7 +934,10 @@ These annotations are skipped for remote paths."
   "Return original category reported by completion metadata."
   ;; NOTE: Use `alist-get' instead of `completion-metadata-get' to bypass our
   ;; `marginalia--completion-metadata-get' advice!
-  (alist-get 'category marginalia--metadata))
+  (when-let (cat (alist-get 'category marginalia--metadata))
+    ;; Ignore Emacs 28 symbol-help category in order to ensure that the
+    ;; categories are refined to our categories function and variable.
+    (and (not (eq cat 'symbol-help)) cat)))
 
 (defun marginalia-classify-symbol ()
   "Determine if currently completing symbols."
